// various explainers that could be related to multiple problems. They are gathered here and added at the end of the email to avoid pasting them multiple times

export type ExplainerKey = 'cookies_are_pii' | 'responsibility_for_third_parties';

export const Explainers: Record<ExplainerKey, (zaimek_index: 0 | 1 | 2 | 3) => JSX.Element> = {
    cookies_are_pii: () => (
        <>
            <h2>Ciasteczka stanowią dane osobowe</h2>
            <p>
                Sztucznie wygenerowane identyfikatory przechowywane w plikach Cookies stanowią dane
                osobowe. Wskazuje na to wprost Art. 4. pkt 1. RODO, wymieniając „identyfikator
                internetowy” i „numer identyfikacyjny” jako przykłady danych osobowych. Losowe
                przypisane identyfikatory mogą nie zawierać imienia i nazwiska osoby, której
                dotyczą, ani nie prowadzić wprost do ich ustalenia, ale pozwalają odróżnić jedną,
                daną konkretną osobę, od innych.
            </p>
            <p>
                Por. komentarz z D. Lubasz [w:] Ochrona Danych Osobowych [red.] D. Lubasz, Warszawa
                2020 r., str. 81:
            </p>
            <p>
                <em>
                    Zidentyfikowaną osobą fizyczną jest osoba, której tożsamość jest ustalona -
                    bezpośrednio i natychmiast, czyli taka, którą bezpośrednio można wskazać,
                    wyodrębnić lub wyróżnić z określonej zbiorowości.{' '}
                    <strong>Nie musi to natomiast polegać na podaniu jej imienia nazwiska</strong>.
                    Konstatacja ta jest zwłaszcza istotna w środowisku cyfrowym, w którym
                    identyfikacja sprowadza się do oznaczenia danego użytkownika w celu wywierania
                    na niego określonego wpływu. (...) Możliwą do zidentyfikowania jest osoba,
                    której tożsamość dopiero administrator może ustalić -{' '}
                    <strong>niezależnie od tego, czy to zrobi, czy nie</strong>.
                </em>
            </p>
            <p>
                Podobnie za{' '}
                <em>
                    P. Litwiński [w:] Rozporządzenie UE w sprawie ochrony osób fizycznych w związku
                    z przetwarzaniem danych osobowych i w sprawie swobodnego przepływu takich
                    danych, Komentarz [red.] P. Litwiński, Warszawa 2018 r.
                </em>
                :
            </p>
            <p>
                <em>
                    Jak zwrócono uwagę w nauce prawa, identyfikacja osoby powinna być rozumiana jako
                    możliwość „fizycznego” wskazania tejże osoby, nie zaś jako ustalenie
                    podstawowych danych tej osoby (...). Analogicznie,{' '}
                    <em>identyfikacja osoby nie wymaga znajomości jej imienia lub nazwiska</em>,
                    wymaga natomiast znajomości pewnych unikalnych cech tej osoby, które odróżniają
                    ją od innych osób (...). W ten sam sposób należy więc rozumieć zwrot „można
                    zidentyfikować” - nie tylko jako możliwość odniesienia konkretnej informacji do
                    konkretnej osoby, lecz także jako możliwość wskazania tej osoby, rozumianego
                    jako faktyczne wyodrębnienie jej spośród innych osób.
                </em>
            </p>
        </>
    ),
    responsibility_for_third_parties: () => (
        <>
            <h2>Administrator strony ponosi odpowiedzialność za skrypty podmiotów trzecich</h2>
            <p>
                W wypadku, gdy ujawnienie czy dostęp do danych osobowych zostało dokonane przez
                skrypty podmiotów trzecich (np. Google, Facebook, itp), których autorem nie jest
                Administrator strony, Administrator wciąż jest odpowiedzialny za procesy
                przetwarzania danych osobowych, jakie realizują te skrypty - w myśl treści{' '}
                <a href="https://curia.europa.eu/juris/document/document.jsf?text=&docid=216555&pageIndex=0&doclang=PL&mode=lst&dir=&occ=first&part=1&cid=1254905">
                    wyroku TSUE w sprawie C-40/17
                </a>
            </p>
        </>
    ),
};
